[PATCH] D157127: [CodeGen][AArch64] Don't split functions with a red zone on AArch64

Leonard Chan via Phabricator via llvm-commits llvm-commits at lists.llvm.org
Fri Aug 4 12:30:03 PDT 2023


This revision was not accepted when it landed; it landed in state "Needs Review".
This revision was landed with ongoing or failed builds.
This revision was automatically updated to reflect the committed changes.
Closed by commit rGfe195781ad2f: [hwasan] Enable leak detection in hwasan for Fuchsia by default (authored by leonardchan).
Herald added subscribers: Sanitizers, Enna1, abrachet, phosek.
Herald added a project: Sanitizers.

Changed prior to commit:
  https://reviews.llvm.org/D157127?vs=547303&id=547310#toc

Repository:
  rG LLVM Github Monorepo

CHANGES SINCE LAST ACTION
  https://reviews.llvm.org/D157127/new/

https://reviews.llvm.org/D157127

Files:
  compiler-rt/lib/hwasan/hwasan.cpp


Index: compiler-rt/lib/hwasan/hwasan.cpp
===================================================================
--- compiler-rt/lib/hwasan/hwasan.cpp
+++ compiler-rt/lib/hwasan/hwasan.cpp
@@ -86,9 +86,11 @@
     cf.clear_shadow_mmap_threshold = 4096 * (SANITIZER_ANDROID ? 2 : 8);
     // Sigtrap is used in error reporting.
     cf.handle_sigtrap = kHandleSignalExclusive;
-    // For now only tested on Linux. Other plantforms can be turned on as they
-    // become ready.
-    cf.detect_leaks = cf.detect_leaks && SANITIZER_LINUX && !SANITIZER_ANDROID;
+    // For now only tested on Linux and Fuchsia. Other plantforms can be turned
+    // on as they become ready.
+    constexpr bool can_detect_leaks =
+        (SANITIZER_LINUX && !SANITIZER_ANDROID) || SANITIZER_FUCHSIA;
+    cf.detect_leaks = cf.detect_leaks && can_detect_leaks;
 
 #if SANITIZER_ANDROID
     // Let platform handle other signals. It is better at reporting them then we


-------------- next part --------------
A non-text attachment was scrubbed...
Name: D157127.547310.patch
Type: text/x-patch
Size: 945 bytes
Desc: not available
URL: <http://lists.llvm.org/pipermail/llvm-commits/attachments/20230804/8cd66bc4/attachment.bin>


More information about the llvm-commits mailing list